/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtQml module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

import QtQuick 2.2
import QtQuick.XmlListModel 2.0
import "content"

Rectangle {
    id: window
    anchors.fill: parent
    gradient: Gradient {
        GradientStop { position: 0.0; color: "#eeeeee" }
        GradientStop { position: 0.1; color: "#ffffff" }
        GradientStop { position: 0.9; color: "#ffffff" }
        GradientStop { position: 1.0; color: "#bbbbbb" }
    }

    property int listWidth: window.width*0.35
    property string currentFeed: "feeds.bbci.co.uk/news/rss.xml"
    property bool loading: feedModel.status == XmlListModel.Loading

    RssFeeds { id: rssFeeds }

    XmlListModel {
        id: feedModel
        source: "http://" + window.currentFeed
        query: "/rss/channel/item"

        XmlRole { name: "title"; query: "title/string()" }
        XmlRole { name: "link"; query: "link/string()" }
        XmlRole { name: "description"; query: "description/string()" }

        onStatusChanged: {
            if (status == XmlListModel.Error) {
                networkErrorBox.opacity = 1.0
            } else if (status == XmlListModel.Ready) {
                networkErrorBox.opacity = 0.0
            }
        }
    }

    Row {
        Rectangle {
            id: categoryContent
            width: window.listWidth; height: window.height
            color: "#efefef"

            ListView {
                id: categories
                anchors.fill: parent
                model: rssFeeds
                delegate: CategoryDelegate {}
                highlight: Rectangle { color: "steelblue" }
                highlightMoveVelocity: 9999999
            }
            ScrollBar {
                scrollArea: categories; height: categories.height; width: 8
                anchors.right: categories.right
            }
        }
        ListView {
            id: list
            width: window.width - window.listWidth; height: window.height
            model: feedModel
            delegate: NewsDelegate {}

            Item {
                id: networkErrorBox
                opacity: 0
                anchors.fill: parent

                Text {
                    anchors.centerIn: parent
                    text: qsTr("Sorry! No network connection")
                }
            }
        }
    }


    ScrollBar { scrollArea: list; height: list.height; width: 8; anchors.right: window.right }
    Rectangle { x: window.listWidth; height: window.height; width: 1; color: "#cccccc" }
}
